@@ -6,10 +6,10 @@ from typing import Type, List, cast, Union, Iterable
 import spacy
 from collections_extended import RangeMap
 from pydantic import BaseModel, Field
+from pymultirole_plugins.util import comma_separated_to_list
 from pymultirole_plugins.v1.annotator import AnnotatorParameters, AnnotatorBase
 from pymultirole_plugins.v1.schema import Document, Span, Annotation, Term
 from spacy.cli.download import download_model, get_compatibility, get_version
-from spacy.errors import OLD_MODEL_SHORTCUTS
 from spacy.language import Language
 from spacy.matcher import Matcher
 from unidecode import unidecode
@@ -19,10 +19,6 @@ logger = logging.getLogger(__name__)
 
 
 class AcronymsParameters(AnnotatorParameters):
-    model: str = Field(
-        "en_core_web_sm",
-        description="Name of the [spacy model](https://spacy.io/models) to use for NER extraction",
-    )
     short_label: str = Field(
         "Acronym", description="Label of the annotation for the short form of acronyms"
     )
@@ -36,16 +32,27 @@ class AcronymsParameters(AnnotatorParameters):
     max_size: int = Field(6, description="Maximum size of acronyms")
 
 
+SUPPORTED_LANGUAGES = "en,fr,de,nl,es,pt,it,zh,ar,hi,ur,fa,ru"
+
+
 class AcronymsAnnotator(AnnotatorBase):
-    """Acronyms annotator."""
+    """Acronyms annotator.
+    #languages:""" + SUPPORTED_LANGUAGES
 
     def annotate(
-        self, documents: List[Document], parameters: AnnotatorParameters
+            self, documents: List[Document], parameters: AnnotatorParameters
     ) -> List[Document]:
         params: AcronymsParameters = cast(AcronymsParameters, parameters)
-        # Create parsing context with time and language information
-        nlp, matcher = get_nlp(params.model, params.max_size)
+        supported_languages = comma_separated_to_list(SUPPORTED_LANGUAGES)
+
         for document in documents:
+
+            # Retrieve nlp pipe
+            lang = document_language(document, None)
+            if lang is None or lang not in supported_languages:
+                raise AttributeError(f"Metadata language {lang} is required and must be in {SUPPORTED_LANGUAGES}")
+            nlp, matcher = get_nlp(lang, params.max_size)
+
             document.annotations = []
             if not document.sentences:
                 document.sentences = [Span(start=0, end=len(document.text))]
@@ -53,7 +60,7 @@ class AcronymsAnnotator(AnnotatorBase):
             sents_stexts = []
             for s in document.sentences:
                 if s.end > s.start:
-                    sents_stexts.append((s, document.text[s.start : s.end]))
+                    sents_stexts.append((s, document.text[s.start: s.end]))
             sents, stexts = zip(*sents_stexts)
             docs = nlp_clean(nlp, stexts)
             acro_dict = defaultdict(list)
@@ -68,8 +75,8 @@ class AcronymsAnnotator(AnnotatorBase):
                     acro = None
                     long_texts = None
                     if (
-                        seen_offsets.get(start) is None
-                        and seen_offsets.get(end - 1) is None
+                            seen_offsets.get(start) is None
+                            and seen_offsets.get(end - 1) is None
                     ):
                         seen_offsets[start:end] = acro_def
                         if acro_def == "long2short":
@@ -77,7 +84,7 @@ class AcronymsAnnotator(AnnotatorBase):
                             long = resolve_longform(
                                 acro_def,
                                 acro,
-                                doc[max(0, start - 2 * params.max_size) : start + 1],
+                                doc[max(0, start - 2 * params.max_size): start + 1],
                             )
                             long_texts = [long.text] if long else None
                         elif acro_def == "short2long":
@@ -147,8 +154,25 @@ class AcronymsAnnotator(AnnotatorBase):
         return AcronymsParameters
 
 
+def document_language(doc: Document, default: str = None):
+    if doc.metadata is not None and 'language' in doc.metadata:
+        return doc.metadata['language']
+    return default
+
+
+# Deprecated model shortcuts, only used in errors and warnings
+MODEL_SHORTCUTS = {
+    "en": "en_core_web_sm", "de": "de_core_news_sm", "es": "es_core_news_sm",
+    "pt": "pt_core_news_sm", "fr": "fr_core_news_sm", "it": "it_core_news_sm",
+    "nl": "nl_core_news_sm", "el": "el_core_news_sm", "nb": "nb_core_news_sm",
+    "lt": "lt_core_news_sm", "xx": "xx_ent_wiki_sm", "zh": "zh_core_web_sm",
+    "ru": "ru_core_news_sm"
+}
+
+
 @lru_cache(maxsize=None)
-def get_nlp(model, max_size):
+def get_nlp(lang, max_size):
+    model = MODEL_SHORTCUTS.get(lang, lang)
     try:
         nlp: Language = spacy.load(model)
     except BaseException:
@@ -175,12 +199,12 @@ def load_spacy_model(model, *pip_args):
     suffix = "-py3-none-any.whl"
     dl_tpl = "{m}-{v}/{m}-{v}{s}#egg={m}=={v}"
     model_name = model
-    if model in OLD_MODEL_SHORTCUTS:
+    if model in MODEL_SHORTCUTS:
         msg.warn(
             f"As of spaCy v3.0, shortcuts like '{model}' are deprecated. Please "
-            f"use the full pipeline package name '{OLD_MODEL_SHORTCUTS[model]}' instead."
+            f"use the full pipeline package name '{MODEL_SHORTCUTS[model]}' instead."
         )
-        model_name = OLD_MODEL_SHORTCUTS[model]
+        model_name = MODEL_SHORTCUTS[model]
     compatibility = get_compatibility()
     version = get_version(model_name, compatibility)
     download_model(dl_tpl.format(m=model_name, v=version, s=suffix), pip_args)
@@ -238,7 +262,7 @@ def resolve_longform(acro_def, short_form, segment):
         i: unidecode(t.text).upper()[0]
         for i, t in enumerate(segment)
         if t.pos_ in ["PUNCT", "NOUN", "ADJ", "VERB", "PROPN", "ADV"]
-        and t.text not in [".", "-", ","]
+           and t.text not in [".", "-", ","]
     }
     long = compare_signature(acro_def, acro_upper, seg_upper, segment)
     if long:
@@ -258,7 +282,7 @@ def compare_signature(acro_def, acro_upper, seg_upper, segment):
         long_form = segment[start:end]
         # Accept an insertion of 2 tokens between long and short forms
         if (acro_def == "long2short" and segment.end - long_form.end <= 2) or (
-            acro_def == "short2long" and long_form.start - segment.start <= 2
+                acro_def == "short2long" and long_form.start - segment.start <= 2
         ):
             return long_form
         else:
