@@ -27,9 +27,9 @@ def test_acronyms():
         text += sent + "\n\n"
         send = len(text)
         sentences.append(Sentence(start=sstart, end=send))
-    doc = Document(text=text, sentences=sentences)
+    doc = Document(text=text, sentences=sentences, metadata={'language': 'fr'})
     annotator = AcronymsAnnotator()
-    parameters = AcronymsParameters(model="fr")
+    parameters = AcronymsParameters()
     docs: List[Document] = annotator.annotate([doc], parameters)
     doc0 = docs[0]
     acros = ["CE", "TIC", "MoDem", "LREM", "LR", "CESU", "ZRR", "CSE", "CHSCT"]
